@@ -1,13 +1,11 @@
 import os
-import yaml
-import json
-import time
 import boto3
 from botocore.config import Config
 from inquirer import prompt, Confirm, Text
 from datetime import datetime
 from dateutil import tz
 from prettytable import PrettyTable
+from cfn_visualizer import visualizer
 
 from bastion_cli.validators import stack_name_validator
 
@@ -60,7 +58,6 @@ class DeployCfn:
                 Capabilities=['CAPABILITY_NAMED_IAM']
             )
             stack_id = response['StackId']
-            event_count = 0
 
             while True:
                 # 1. get stack status
@@ -92,20 +89,7 @@ class DeployCfn:
                     break
 
                 else:
-                    events = self.client.describe_stack_events(StackName=self.name)['StackEvents']
-                    if len(events) > event_count:  # new events
-                        for i in range(0, len(events) - event_count):
-                            event = ' {:>11} | \x1b[{}{:<27}\x1b[0m | {:<26} | {}'.format(
-                                self.get_timestamp(events[i]['Timestamp']),
-                                self.get_color(events[i]['ResourceStatus']),
-                                events[i]['ResourceStatus'],
-                                events[i]['ResourceType'],
-                                events[i].get('ResourceStatusReason', ''))
-                            print(event)
-
-                            event_count = len(events)
-
-                    time.sleep(1)
+                    visualizer(self.client, self.name)
 
         else:
             print('Done!\n\n')
